<?php
$lang['address'] = 'Adresse ';
$lang['add_category'] = 'Ajouter une cat&eacute;gorie';
$lang['add_icon'] = 'Ajouter une ic&ocirc;ne';
$lang['add_map'] = 'Ajouter une carte';
$lang['add_map_point'] = 'Ajouter un point sur la carte';
$lang['add_point_for_map'] = 'Ajouter un point sur la carte &quot;%s&quot;';
$lang['aerial'] = 'A&eacute;rien';
$lang['anchor_x'] = 'Localisation de l&#039;Ancre X Pixel';
$lang['anchor_y'] = 'Localisation de l&#039;Ancre Y Pixel';
$lang['apply'] = 'Appliquer';
$lang['ask_delete_icon'] = '&Ecirc;tes vous certain(e) de vouloir supprimer cette ic&ocirc;ne de la liste (aucun fichier sera supprim&eacute;)';
$lang['ask_reset_icons'] = '&Ecirc;tes vous certain(e) de vouloir supprimer toutes les ic&ocirc;nes et de revenir aux param&egrave;tres par d&eacute;faut ?';
$lang['baloon_maptemplate'] = 'Gabarit du ballon';
$lang['cancel'] = 'Annuler';
$lang['category_template'] = 'Gabarit : vue de cat&eacute;gorie';
$lang['center_lat'] = 'Latitude du centre ';
$lang['center_lon'] = 'Longitude du centre ';
$lang['clearcache'] = 'Effacer le cache de g&eacute;olocalisation';
$lang['click'] = 'Clic';
$lang['combine_points'] = 'Grouper les points selon leur proximit&eacute; ';
$lang['combined_points_icon'] = 'Ic&ocirc;ne &agrave; utiliser pour les groupes de points ';
$lang['controls'] = 'Contr&ocirc;les ';
$lang['controls_size'] = 'Taille des contr&ocirc;les ';
$lang['default'] = 'D&eacute;faut';
$lang['default_icon'] = 'Ic&ocirc;ne par d&eacute;faut ';
$lang['default_templates'] = 'Gabarits par d&eacute;faut';
$lang['delete'] = 'Supprimer';
$lang['delete_icon'] = 'Supprimer cette ic&ocirc;ne';
$lang['delete_map'] = 'Supprimer la carte';
$lang['delete_map_point'] = 'Supprimer un point de carte ';
$lang['description'] = 'Description ';
$lang['directions'] = 'Montrer les liens &quot;itin&eacute;raire&quot; ';
$lang['directions_dest'] = 'O&ugrave; afficher l&#039;itin&eacute;raire ';
$lang['directions_units'] = 'Unit&eacute; de distance ';
$lang['dirform_maptemplate'] = 'Gabarit : formulaire d&#039;itin&eacute;raire';
$lang['dropdown'] = 'Liste d&eacute;roulante';
$lang['edit'] = 'Modifier';
$lang['edit_category'] = 'Modifier la cat&eacute;gorie de points&nbsp;';
$lang['edit_icon'] = 'Modifier cette ic&ocirc;ne';
$lang['edit_map'] = 'Modifier la carte';
$lang['edit_map_point'] = 'Modifier le point de carte';
$lang['edit_map_points'] = 'Modifier les points de la carte';
$lang['edit_points_for_map'] = 'Modifier les points de la carte &quot;%s&quot;';
$lang['error_browser_incompatible'] = 'Votre navigateur ne peut afficher les cartes Google Maps';
$lang['error_cannotdelete'] = 'Cet objet ne peut &ecirc;tre supprim&eacute;';
$lang['error_deletecategory'] = 'Un probl&egrave;me est survenu lors de la suppression de la cat&eacute;gorie';
$lang['error_invalidparams'] = 'Un ou plusieurs param&egrave;tres sont manquants ou invalides';
$lang['error_mapelem_notfound'] = '&Eacute;l&eacute;ment de carte non trouv&eacute;';
$lang['error_nameexists'] = 'Un objet avec ce m&ecirc;me nom existe d&eacute;j&agrave;';
$lang['error_noapikey'] = 'La cl&eacute; Google Api est vide';
$lang['error_noapikey2'] = 'La cl&eacute; Google Api est vide. Ce module ne fonctionnera pas correctement tant qu&#039;il ne sera pas param&eacute;tr&eacute; avec une cl&eacute; valide distribu&eacute;e par Google.';
$lang['error_notfound'] = 'L&#039;objet demand&eacute; n&#039;a pas &eacute;t&eacute; trouv&eacute;';
$lang['error_permissiondenied'] = 'Vous n&#039;avez pas les permissions n&eacute;cessaire pour excecuter cette action';
$lang['friendlyname'] = 'Cartes Google Maps (CG)';
$lang['from'] = 'D&eacute;part';
$lang['get_directions'] = 'Voir l&#039;itin&eacute;raire';
$lang['google_api_key'] = 'Cl&eacute; Google API ';
$lang['help'] = '<h3>Que fait ce module ?</h3>
  <p>This module provides a quick, convenient, yet flexible and extendable way to place google maps on a page providing a number of built in functions, and providing easy extendability for those familiar with Javascript and the Google Maps API&#039;;
<h3>Fonctionnalit&eacute;s :</h3>
<ul>
  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
  <li>Flexible marker icon management.</li>
  <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
  <li>Infowindow content can be specified using HTML</li>
  <li>Support de Streetview</li>
  <li>The ability to display a sidebar of all markers associated with a map.</li>
  <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
  <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
  <li>Reads sensor information from GPS sensors on mobile devices.</li>
  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
  <li>Uses jquery for advanced DOM manipulation.</li>
</ul>
<h3>Comment l&#039;utiliser ?</h3>
<ul>
<li>Install the module via the normal methods</li>
<li>Setup your users and groups with the appropriate permissions:
  <ul>
    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
  </ul>
</li>
<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
<li>Cr&eacute;ez un ou plusieurs points sur votre carte en cliquant sur l&#039;ic&ocirc;ne &quot;point&quot; soit en renseignant les coordonn&eacute;es g&eacute;ographiques (latitude et longitude) soit en renseignant l&#039;adresse.</li>
<li>Ajoutez le tag {CGGoogleMaps} dans une page ou un gabarit. Vous avez termin&eacute;.</li>
</ul>
<br/>
<h3>Ajouter des points dynamiques &agrave; une carte</h3>
<p>Vous pouvez utiliser Smarty pour ajouter des points dynamiques venant d&#039;un autre module. Par exemple, vous pouvez construire une carte de vos membres avec plusieurs points g&eacute;r&eacute;s par un autre module (comme CompanyDirectory, FrontEndUsers ou CGUserDirectory).</p>
<h4>Le plugin Smarty {cggm_add_dynpoint}</h4>
<p>Ce plugin Smarty <em>(disponible uniquement quand le module Cartes Google Maps est install&eacute;)</em> permet d&#039;ajouter des points dynamique sur une carte. Pour cela, ins&eacute;rez le code suivant dans un gabarit.</p>
<h4>Utilisation :</h4>
<pre><code>{cggm_add_dynpoint map=1 name=&#039;Paris&#039; address=&#039;Paris, France&#039; icon=&#039;food&#039;}<br />{CGGoogleMaps map=&#039;1&#039;}</code></pre><br/>
<h4>Param&egrave;tres :</h4>
  <ul> 
<li><strong>requis</strong> - map : l&#039;ID (integer) de la carte &agrave; laquelle vous voulez ajouter le point</li>
<li><strong>requis</strong> - name : le nom du point &agrave; ajouter</li>
<li><em>facultatif</em> - desc/description : le contenu HTML qui sera affich&eacute; dans la bo&icirc;te d&#039;information</li>
<li><em>facultatif</em> - address : l&#039;adresse du lieu que vous ajoutez (vous devez mettre une adresse ou des param&egrave;tres de latitude et de longitude)</li>
<li><em>facultatif</em> - lat : la latitude du point &agrave; ajouter</li>
<li><em>facultatif</em> - long : la longitude du point &agrave; ajouter</li>
<li><em>facultatif</em> - category : une liste de catr&eacute;gories de points, s&eacute;par&eacute;es par des virgules (there is no need for the categories to already exists)</li>
<li><em>facultatif</em> - tooltip : une bulle d&#039;information &agrave; afficher quand on survole un point.</li>
<li><em>facultatif</em> - icon : le nom de l&#039;ic&ocirc;ne &agrave; utiliser pour ce point.</li>
  </ul>
<br/>
<p><strong>Note :</strong> Les coordonn&eacute;es g&eacute;ographiques (latitude/longitude) ou l&#039;adresse doivent imp&eacute;rativement &ecirc;tre renseign&eacute;s.</p>
<p><strong>Note :</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
</ul>
<h3>Informations d&#039;upgrade :</h3>
<p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
<p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Requirements</h3>
<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['height'] = 'Hauteur ';
$lang['help_anchor_location'] = '<strong>Remarque :</ strong>&nbsp;le point d&#039;attache sp&eacute;cifie l&#039;emplacement en pixel (par rapport au coin sup&eacute;rieur gauche de l&#039;image), o&ugrave; l&#039;ic&ocirc;ne doit &ecirc;tre ancr&eacute;e au marqueur. Si aucune valeur n&#039;est sp&eacute;cifi&eacute;e, le centre de l&#039;ic&ocirc;ne sera utilis&eacute;e';
$lang['help_icon_url'] = 'Indiquez l&#039;URL de l&#039;image PNG pr&eacute;-t&eacute;l&eacute;charg&eacute;e. Cette image ne devrait pas &ecirc;tre plus grande que 32x32, et devrait supporter la transparence. L&#039;URL peut &ecirc;tre sp&eacute;cifi&eacute; par rapport &agrave; la racine de votre installation';
$lang['help_param_defer'] = 'Indiquez que toutes les balises JavaScript doivent avoir l&#039;attribut defer positionn&eacute;. Cela peut &ecirc;tre utile pour des probl&egrave;mes avec IE7 et IE8 si Internet Explorer tente d&#039;ex&eacute;cuter du code JavaScript sur une page partiellement charg&eacute;e.';
$lang['help_param_map'] = 'Indiquez l&#039;ID ou le nom de la carte &agrave; utiliser pour la pose de la carte google. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, la carte par d&eacute;faut (le cas &eacute;ch&eacute;ant) est utilis&eacute;e.';
$lang['help_param_maptemplate'] = 'Indiquez le nom d&#039;un gabarit de carte existant -et non d&eacute;finit &quot;par d&eacute;faut&quot;- &agrave; utiliser pour cet affichage. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute;, le gabarit de carte par d&eacute;faut sera utilis&eacute;';
$lang['help_param_zoomlevel'] = '(entier) Sp&eacute;cifie le niveau de zoom de la carte - outrepasse le param&egrave;tre de zoom de la carte. Valeurs : de 1 &agrave; 17';
$lang['help_param_zoomencompass'] = '(bool&eacute;en) Sp&eacute;cifie si l&#039;entourage du zoom doit &ecirc;tre utilis&eacute; pour la carte';
$lang['hide_directions'] = 'Masquer l&#039;itin&eacute;raire';
$lang['horizontal_bar'] = 'Barre horizontale';
$lang['hybrid'] = 'Hybride';
$lang['id'] = 'Id ';
$lang['icon'] = 'Ic&ocirc;ne ';
$lang['imperial'] = 'Imperiale';
$lang['info'] = 'Informations ';
$lang['info_address_latlong'] = 'Note : renseignez une adresse <strong>ou</strong> les coordonn&eacute;es (latitude et longitude) pour votre point.  Si l&#039;adresse et les coordonn&eacute;es sont toutes deux renseign&eacute;es, ce seront les coordonn&eacute;es qui seront prises en compte.';
$lang['info_anchor_x'] = 'Position d&#039;ancrage (pixel X) de la fen&ecirc;tre d&#039;information';
$lang['info_anchor_y'] = 'Position d&#039;ancrage (pixel Y) de la fen&ecirc;tre d&#039;information';
$lang['info_bounds_fudge'] = 'Quand &quot;Entourage du zoom&quot; est s&eacute;lectionn&eacute;, vous pouvez saisir un pourcentage <em>(en d&eacute;cimal)</em> d&#039;agrandissement des limites de la carte afin que celle-ci dispose d&#039;une &quot;marge&quot; autour des points.';
$lang['info_category_panel'] = 'Souhaitez-vous afficher un panneau avec la liste des cat&eacute;gories des points de la carte, et permettre d&#039;afficher/masquer les points en fonction de leur cat&eacute;gorie ?';
$lang['info_center_lat'] = 'La latitude du centre est optionnelle. Si elle est sp&eacute;cifi&eacute;e, elle sera utilis&eacute;e pour centrer la carte. Saisir une valeur d&eacute;cimale en degr&eacute;s, par ex. : -123.45';
$lang['info_center_lon'] = 'La longitude du centre est optionnelle. Si elle est sp&eacute;cifi&eacute;e, elle sera utilis&eacute;e pour centrer la carte. Saisir une valeur d&eacute;cimale en degr&eacute;s, par ex. : -123.45';
$lang['info_combine_points'] = 'Si &quot;Oui&quot;, les points situ&eacute;s &agrave; proximit&eacute; les uns des autres (selon rayon &agrave; d&eacute;finir) vont &ecirc;tre group&eacute;s en un seul point sur la carte. Cette fonction est utile pour faciliter la s&eacute;lection de points plac&eacute;s &agrave; des coordonn&eacute;es identiques ou quasi-similaires. Cette fonction est ind&eacute;pendante du niveau de zoom.';
$lang['info_controls'] = 'Afficher les contr&ocirc;les de zoom et de d&eacute;placement de la carte ?';
$lang['info_controls_size'] = 'Choisir la taille des contr&ocirc;les sur la carte';
$lang['info_default_icon'] = 'L&#039;ic&ocirc;ne par d&eacute;faut est utilis&eacute;e si aucune ic&ocirc;ne n&#039;est d&eacute;finie pour un point de carte';
$lang['info_directions'] = 'Autoriser les visiteurs &agrave; utiliser la recherche d&#039;itin&eacute;raire';
$lang['info_directions_dest'] = 'Choisir la mani&egrave;re dont les itin&eacute;raires doivent &ecirc;tre affich&eacute;s : dans une nouvelle fen&ecirc;tre ou directement sur la carte';
$lang['info_directions_units'] = 'Choisir les unit&eacute;s de distance pour les itin&eacute;raires : m&eacute;triques ou imp&eacute;riales';
$lang['info_height'] = 'Choisir la hauteur de la carte (en pixels)';
$lang['info_icon_selection'] = 'Par d&eacute;faut, quelle ic&ocirc;ne doit &ecirc;tre affich&eacute;e pour les points quand le panneau de cat&eacute;gories est affich&eacute; ?';
$lang['info_info_trigger'] = 'Choisir l&#039;&eacute;v&egrave;nement qui d&eacute;clenche l&#039;ouverture de la bulle d&#039;informations d&#039;un point';
$lang['info_info_window'] = 'Afficher une bulle d&#039;informations pour chaque point ?';
$lang['info_infowindow_height'] = 'Choisir la hauteur (en pixels) de la bulle d&#039;informations';
$lang['info_infowindow_width'] = 'Choisir la largeur (en pixels) de la bulle d&#039;informations';
$lang['info_map_type'] = 'Choisir le type de carte par d&eacute;faut (l&#039;utilisateur pourra changer le type de carte si les boutons de changement de type de carte sont affich&eacute;s)';
$lang['info_nav_control_opt'] = 'Choisir le type de contr&ocirc;les sur la carte';
$lang['info_point_combine_fudge'] = 'Plus cette valeur est basse, moins les points proches les uns des autres vont &ecirc;tre group&eacute;s en un unique point. Les valeurs n&eacute;gatives ne sont pas valides.';
$lang['info_point_combine_icon'] = 'Choisir l&#039;ic&ocirc;ne &agrave; utiliser pour pr&eacute;senter sur la carte un point regroupant plusieurs points dans une m&ecirc;me zone';
$lang['info_scalecontrols'] = 'Une &eacute;chelle peut &ecirc;tre afficher dans le coin inf&eacute;rieur droit de la carte';
$lang['info_sensor'] = 'Certains navigateurs (notamment les navigateurs des smartphones) peuvent fournir des informations de latitude et longitude. Souhaitez-vous activer cette fonction ?';
$lang['info_sidebar'] = 'Afficher une barre lat&eacute;rale pr&eacute;sentant la liste des points de la carte ?';
$lang['info_sv_controls'] = 'Afficher les boutons &quot;StreetView&quot; (vue des photos des rues) sur la carte ?';
$lang['info_sv_radius'] = 'Si Streetview est activ&eacute; pour une carte, &agrave; quelle distance (en m&egrave;tres) faut-il rechercher une situation valide de vue Streetview. Ceci est important dans les zones rurales o&ugrave; Streetview n&#039;est pas disponible dans toutes les rues.';
$lang['info_sysdflt_baloon_template'] = 'Gabarit de bulle d&#039;informations par d&eacute;faut';
$lang['info_sysdflt_category_template'] = 'Gabarit de liste des cat&eacute;gories par d&eacute;faut';
$lang['info_sysdflt_dirform_template'] = 'Gabarit de saisie d&#039;itin&eacute;raire par d&eacute;faut';
$lang['info_sysdflt_js_template'] = 'Gabarit Javascript par d&eacute;faut';
$lang['info_sysdflt_map_template'] = 'Gabarit de carte par d&eacute;faut';
$lang['info_sysdflt_sidebar_template'] = 'Gabarit de la barre lat&eacute;rale par d&eacute;faut';
$lang['info_sysdflt_template'] = 'Ce formulaire permet de pr&eacute;ciser le contenu qui sera affich&eacute; lorsque vous cr&eacute;ez un nouveau gabarit de ce type. Modifier le contenu de ce formulaire n&#039;aura pas d&#039;effet imm&eacute;diat sur votre site web';
$lang['info_type_control_opt'] = 'Choisir la mani&egrave;re dont vont &ecirc;tre affich&eacute;s les contr&ocirc;les de la carte';
$lang['info_width'] = 'Choisir la largeur de la carte (en pixels)';
$lang['infowindow_width'] = 'Largeur des bulles d&#039;informations ';
$lang['infowindow_height'] = 'Hauteur des bulles d&#039;informations ';
$lang['info_type_controls'] = 'Permettre aux utilisateur de changer le type de carte ?';
$lang['info_zoom'] = 'Choisir le niveau de zoom initial (ce param&egrave;tre n&#039;est pas pris en compte si &quot;Entourage du zoom&quot; est utilis&eacute;)';
$lang['info_zoom_encompass'] = 'Le niveau de zoom par d&eacute;faut de la carte doit-il englober tous les points ?';
$lang['js_template'] = 'Gabarit Javascript';
$lang['large'] = 'Large ';
$lang['latitude'] = 'Latitude ';
$lang['latlong'] = 'Latitude / Longitude ';
$lang['location'] = 'Lieu';
$lang['longitude'] = 'Longitude ';
$lang['make_default'] = 'Faire de cette ic&ocirc;ne l&#039;ic&ocirc;ne par d&eacute;faut';
$lang['marker_categories'] = 'Cat&eacute;gories de points';
$lang['marker_icons'] = 'Ic&ocirc;nes de points';
$lang['marker_skipped'] = 'La g&eacute;olocalisation (addresse en coordonn&eacute;es lat/long) a &eacute;chou&eacute; pour &quot;%s&quot;';
$lang['map'] = 'Carte';
$lang['maps'] = 'Cartes';
$lang['maptemplate_addedit'] = 'Ajouter/Editer un gabarit de carte';
$lang['map_name'] = 'Nom de la carte ';
$lang['map_template'] = 'Gabarit de carte';
$lang['map_templates'] = 'Gabarits de carte';
$lang['map_type'] = 'Type de carte ';
$lang['metric'] = 'M&eacute;trique';
$lang['moddescription'] = 'Un module complet pour cr&eacute;er des cartes avec Google Maps ou Yahoo Maps. Cr&eacute;ation de cartes, ajout de points, tri par cat&eacute;gories, points dynamiques, etc.';
$lang['mouseover'] = 'Survol de la souris';
$lang['msg_addresscache_cleared'] = 'Cache de g&eacute;olocalisation effac&eacute;';
$lang['msg_categoryadded'] = 'Cat&eacute;gorie ajout&eacute;e';
$lang['msg_categorydeleted'] = 'Cat&eacute;gorie supprim&eacute;e';
$lang['msg_categoryupdated'] = 'Cat&eacute;gorie mise &agrave; jour';
$lang['msg_default_icon_uchanged'] = 'L&#039;ic&ocirc;ne par d&eacute;faut a &eacute;t&eacute; modifi&eacute;e';
$lang['msg_icons_reset'] = 'Les ic&ocirc;nes ont &eacute;t&eacute; r&eacute;mises aux param&egrave;tres par d&eacute;faut';
$lang['msg_icon_removed'] = 'Les ic&ocirc;nes ont &eacute;t&eacute; supprim&eacute;es de la base de donn&eacute;es. Aucun fichier n&#039;a &eacute;t&eacute; supprim&eacute;.';
$lang['msg_icon_updated'] = 'Les informations d&#039;ic&ocirc;nes ont &eacute;t&eacute; modifi&eacute;es';
$lang['name'] = 'Nom&nbsp;';
$lang['nav_control_opt'] = 'Taille des contr&ocirc;les de navigation ';
$lang['none'] = 'Aucun';
$lang['panel'] = 'Panneau';
$lang['points'] = 'Points ';
$lang['point_combine_fudge'] = 'Rayon de groupement des points (selon latitude/longitude) ';
$lang['point_combine_icon'] = 'Ic&ocirc;ne de points group&eacute;s';
$lang['point_name'] = 'Nom du point ';
$lang['point_type'] = 'Type de point ';
$lang['policy_cachefirst'] = 'Consulter d&#039;abord le cache avant de rechercher l&#039;adresse en ligne';
$lang['policy_cacheonly'] = 'Toujours utiliser le cache';
$lang['policy_nocache'] = 'Ne jamais utiliser le cache (rechercher syst&eacute;matiquement en ligne)';
$lang['postinstall'] = 'Le module Cartes Google Maps (CGGoogleMaps) a &eacute;t&eacute; install&eacute;';
$lang['postuninstall'] = 'Le module Cartes Google Maps (CGGoogleMaps) et toutes les donn&eacute;es associ&eacute;es ont &eacute;t&eacute; supprim&eacute;es';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['prompt_bounds_fudge'] = 'Agrandissement des limites de carte avec &quot;Entourage du zoom&quot;';
$lang['prompt_categories'] = 'Categories ';
$lang['prompt_directions'] = 'Itin&eacute;raire&nbsp;';
$lang['prompt_from_here'] = 'Depuis ce point';
$lang['prompt_icon_selection'] = 'S&eacute;lection d&#039;ic&ocirc;ne ';
$lang['prompt_info_window'] = 'Afficher les bulles d&#039;informations ';
$lang['prompt_info_trigger'] = 'Ev&egrave;nement d&#039;ouverture de la bulle d&#039;informations ';
$lang['prompt_lookup_policy'] = 'M&eacute;thode de consultation de carte ';
$lang['prompt_lookup_service'] = 'Service de consultation de carte ';
$lang['prompt_to_here'] = 'Vers ce point';
$lang['prompt_sensor'] = 'Afficher les informations g&eacute;ographiques de l&#039;utilisateur sur la carte ';
$lang['prompt_zoom'] = 'Niveau de zoom ';
$lang['really_uninstall'] = '&Ecirc;tes-vous vraiment certain(e) de vouloir supprimer ce module ?';
$lang['reset'] = 'R&eacute;initialiser';
$lang['reset_icons'] = 'R&eacute;initialiser les ic&ocirc;nes';
$lang['satellite'] = 'Satellite ';
$lang['scalecontrols'] = 'Afficher l&#039;&eacute;chelle ';
$lang['set_dflt_map'] = 'Faire de cette carte la carte par d&eacute;faut';
$lang['show_category_panel'] = 'Afficher le panneau des cat&eacute;gories ';
$lang['sidebar'] = 'Afficher la barre lat&eacute;rale ';
$lang['sidebar_template'] = 'Gabarit de panneau lat&eacute;ral';
$lang['small'] = 'Petit';
$lang['submit'] = 'Envoyer';
$lang['sv_controls'] = 'Afficher les contr&ocirc;les StreetView (vue des rues) ';
$lang['sv_radius'] = 'Rayon de recherche Streetview';
$lang['tab_advanced'] = 'Avanc&eacute;';
$lang['tab_directions'] = 'Itin&eacute;raire&nbsp;';
$lang['tab_jstemplate'] = 'Gabarit Javascript';
$lang['tab_settings'] = 'Param&egrave;tres';
$lang['tab_maptemplate'] = 'Gabarit de carte';
$lang['text'] = 'Texte ';
$lang['to'] = 'Vers';
$lang['type'] = 'Type ';
$lang['type_controls'] = 'Afficher les types de cartes ';
$lang['type_control_opt'] = 'Boutons de type de carte ';
$lang['url'] = 'URL ';
$lang['use_category_icon'] = 'Pr&eacute;f&eacute;rer l&#039;ic&ocirc;ne de la cat&eacute;gorie';
$lang['use_marker_icon'] = 'Pr&eacute;f&eacute;rer l&#039;ic&ocirc;ne du point';
$lang['width'] = 'Largeur ';
$lang['window'] = 'Fen&ecirc;tre';
$lang['zoom_encompass'] = 'Entourage du zoom ';
$lang['qca'] = 'P0-1776187459-1287758187777';
$lang['utma'] = '156861353.1232533107.1323342341.1323687908.1323704115.4';
$lang['utmz'] = '156861353.1323342341.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1323704115';
?>